/* This file is part of Om.  Copyright (C) 2005 Dave Robillard.
 * 
 * Om is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 * 
 * Om is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef OM_H
#define OM_H

#include "config.h"
#include "OmApp.h"


/* Things all over the place access various bits of Om through this.
 * This was a bad design decision, it just evolved this way :/
 * I may refactor it eventually, but it works.
 */

/** \defgroup engine Om engine
 */
namespace Om
{
#ifdef HAVE_LASH
	class LashDriver;
	extern LashDriver* lash_driver;
#endif

	extern OmApp* om;
}

#endif // OM_H
